

set -ex



clang-format-13 --version
test ! -f ${PREFIX}/bin/clang-format
test ! -f ${PREFIX}/bin/c-index-test
exit 0
